#
# spec file for package conntrack-tools
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           conntrack-tools
Version:        1.4.4
Release:        lp151.2.3
Url:            http://conntrack-tools.netfilter.org/
Summary:        Userspace tools for interacting with the Connection Tracking System
License:        GPL-2.0+
Group:          Productivity/Networking/Security

#Git-Clone:	git://git.netfilter.org/conntrack-tools
Source:         ftp://ftp.netfilter.org/pub/conntrack-tools/%name-%version.tar.bz2
Source2:        ftp://ftp.netfilter.org/pub/conntrack-tools/%name-%version.tar.bz2.sig
Source3:        %name.keyring

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  flex >= 2.5.33
BuildRequires:  libtool
BuildRequires:  pkg-config >= 0.21
BuildRequires:  xz
BuildRequires:  pkgconfig(libmnl) >= 1.0.3
BuildRequires:  pkgconfig(libnetfilter_conntrack) >= 1.0.6
BuildRequires:  pkgconfig(libnetfilter_cthelper) >= 1.0.0
BuildRequires:  pkgconfig(libnetfilter_cttimeout) >= 1.0.0
BuildRequires:  pkgconfig(libnetfilter_queue) >= 1.0.2
BuildRequires:  pkgconfig(libnfnetlink) >= 1.0.1
%if 0%{?suse_version} >= 1330
BuildRequires:  pkgconfig(libsystemd) >= 227
%endif

%description
The conntrack-tools are a set of tools targeted at system
administrators. They are conntrack, the userspace command line
interface, and conntrackd, the userspace daemon. The tool conntrack
provides a full featured interface that has replaced the old procfs
interface. Using conntrack, you can view and manage the in-kernel
connection tracking state table from userspace. On the other hand,
conntrackd covers the specific aspects of stateful firewalls to
enable highly available scenarios, and can be used as statistics
collector as well.

%prep
%setup -q
find doc -type f -name '*.orig' -delete

%build
%configure \
%if 0%{?suse_version} >= 1330
	--enable-systemd \
%endif
	--disable-static
# CC       read_config_lex.o
#read_config_lex.l:24:28: fatal error: read_config_yy.h: No such file or
#directory
make %{?_smp_mflags} -j1

%install
b="%buildroot"
make install DESTDIR="$b"
find "$b/%_libdir" -type f -name "*.la" -delete

%files
%defattr(-,root,root)
%doc AUTHORS TODO doc/stats doc/helper 
%_sbindir/conntrack
%_sbindir/conntrackd
%_sbindir/nfct
%_libdir/%name
%_mandir/man5/*
%_mandir/man8/*

%changelog
* Mon Aug 22 2016 jengelh@inai.de
- Update to new upstream release 1.4.4
  * conntrackd: add systemd support
  * conntrack: support delete by label
  * conntrack: add support for netmask filtering
  * conntrack: add support for CIDR notation
  * conntrack: Add missing tables "dying" and "unconfirmed"
  to usage output.
* Wed Sep  9 2015 jengelh@inai.de
- Update to new upstream release 1.4.3
  * conntrack: fix expectation entry creation
  * expect: Fix wrong memset usage
  * cthelper: don't pass up a 0 length queue
  * conntrackd: allow strings with underscore from flex scanner
  * conntrack: fix setting labels in updates
* Thu Jan  8 2015 jengelh@inai.de
- Update to new git snapshot 1.4.2.g26
  * Chromecast/SSDP support, SSDP userspace helper
  * TFTP userspace helper support
  * Support for attaching expectations via nfqueue
  * Fix directory lookup for helper plugins
  * Fixes a possible crash if conntrackd sees DCCP, SCTP and ICMPv6
  traffic and the corresponding kernel modules that track this
  traffic are not available. [bnc#942419, CVE-2015-6496]
* Tue Sep 23 2014 jengelh@inai.de
- Drop gpg-offline build-time requirement; this is now handled by
  the local source validator
* Wed Aug  7 2013 jengelh@inai.de
- Update to new upstream release 1.4.2
  * This release includes bugfixes and the connlabel support.
* Mon Mar  4 2013 jengelh@inai.de
- Update to new upstream release 1.4.1
  * conntrack: add support to dump the dying and unconfirmed list via
  ctnetlink
  * conntrackd: fix deadlock due to wrong nested signal blocking
* Tue Nov 20 2012 sbrabec@suse.cz
- Verify GPG signature
* Mon Oct  8 2012 jengelh@inai.de
- Update to new upstream release 1.4.0
  * This release adds the user-space helper infrastructure which
  includes the RPC portmapper (to support NFSv3) and Oracle*TNS
  helpers.
* Tue Jul 31 2012 jengelh@inai.de
- Update to new upstream release 1.2.2
  * conntrackd: commit operation has to be synchronous
  * conntrackd: implement selective flushing for -t and -F commands
* Thu May 31 2012 jengelh@inai.de
- Resolve compilation failure due to missing #include
* Sat May 26 2012 jengelh@inai.de
- Update to new upstream release 1.2.1
  * Add support for NAT expectations, synchronization of expectation
  class, helper names and expect functions. Filtering by mark is
  now allowed.
* Wed Jan  4 2012 jengelh@medozas.de
- Update to new upstream release 1.0.1
  * add support for mark masks
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Sun Feb 27 2011 jengelh@medozas.de
- new upstream release 1.0.0
  * SYN_SENT2 support for the command line tool conntrack (which was
  added in Linux kernel >= 2.6.31).
  * allow to listen to update and destroy expectation events (it
  requires a Linux kernel >= 2.6.37).
  * conntrack timestamping support with -o ktimestamp (this support
  requires the upcoming Linux 2.6.38).
  * one fix for conntrackd: two very consecutive commit invocations
  with option -c may result in the hang of the second commit
  invocation if the first commit did not finish yet. As a result the
  second commit invocation required a manual SIGTERM.
- Remove redundant %%clean section
* Thu Jul 15 2010 jengelh@medozas.de
- new upstream release 0.9.15
  * support for conntrack zones
  * support for TCP window scale synchronization
  * fixes to option parsing and printouts
* Tue Feb 23 2010 jengelh@medozas.de
- new upstream release: 0.9.14
- use %%_smp_mflags
- wrap description at col 70
* Sun Sep 20 2009 bitshuffler #suse@irc.freenode.org
- Updated to 0.9.13
